@@ -1,11 +1,20 @@
 
 #' @export
 summary.exchangeability_model <- function(object, ...) {
-  ret <- list(
-    call = object$call,
-    basket = summary(object$basket),
-    cluster = summary(object$cluster)
-  )
+  if (!is.na(object$cluster)[1]) {
+    ret <- list(
+      call = object$call,
+      basket = summary(object$basket),
+      cluster = summary(object$cluster)
+    )
+  } else {
+    ret <- list(
+      call = object$call,
+      basket = summary(object$basket),
+      cluster = NA
+    )
+  }
+
   class(ret) <- "mem_summary"
   ret
 }
@@ -22,8 +31,11 @@ print.mem_summary <- function(x, ...) {
   cat("\n")
   cat_line(rule(left = "The Basket Summary", col = "bold"))
   print(x$basket)
-  cat_line(rule(left = "The Cluster Summary", col = "bold"))
-  print(x$cluster)
+
+  if (!is.na(x$cluster)[1]) {
+    cat_line(rule(left = "The Cluster Summary", col = "bold"))
+    print(x$cluster)
+  }
   invisible(x)
 }
 
@@ -31,9 +43,9 @@ make_basket_summary <- function(object) {
   mm <- rbind(object$mean_est, object$median_est)
   rownames(mm) <- c("Mean", "Median")
   ret <- list(
-    null = object$p0, post_prob = object$post.prob,
-    mm_resp = mm, hpd_signif = object$alpha, hpd = object$HPD,
-    ess = object$ESS,
+    null = object$p0, post_prob = object$post_prob,
+    mm_resp = mm, hpd_signif = object$alpha, hpd = object$hpd,
+    ess = object$ess,
     alternative = object$alternative
   )
   class(ret) <- "mem_basket_summary"
@@ -56,13 +68,17 @@ print.mem_basket_summary <- function(x, ...) {
   rownames(a) <- c("Null", "Posterior Prob")
   print(a)
 
+
   # The Mean and Median Response Rates
   cat_line("\nPosterior Mean and Median Response Rates:")
   print(round(x$mm_resp, 3))
 
   # The Highest Posterior Density Interval
-  cat_line("\nHighest Posterior Density Interval with Coverage Probability ",
-    1 - x$hpd_signif, ":")
+  cat_line(
+    "\nHighest Posterior Density Interval with Coverage Probability ",
+    1 - x$hpd_signif,
+    ":"
+  )
   print(round(x$hpd, 3))
 
   # The Effective Sample Size
@@ -78,9 +94,12 @@ make_cluster_summary <- function(object) {
   mm <- rbind(object$mean_est, object$median_est)
   rownames(mm) <- c("Mean", "Median")
   ret <- list(
-    null = object$p0, post_prob = object$post.prob,
-    mm_resp = mm, hpd_signif = object$alpha, hpd = object$HPD,
-    ess = object$ESS,
+    null = object$p0,
+    post_prob = object$post_prob,
+    mm_resp = mm,
+    hpd_signif = object$alpha,
+    hpd = object$hpd,
+    ess = object$ess,
     alternative = object$alternative,
     name = object$name,
     cluster = object$cluster
